Documentation
¶
Overview ¶
Package model is a generated protocol buffer package.
It is generated from these files:
model.proto
It has these top-level messages:
AuthnRequest User Attribute ArtifactResponse
Index ¶
- type ArtifactResponse
- type Attribute
- type AuthnRequest
- func (*AuthnRequest) Descriptor() ([]byte, []int)
- func (m *AuthnRequest) GetAssertionConsumerServiceIndex() uint32
- func (m *AuthnRequest) GetAssertionConsumerServiceURL() string
- func (m *AuthnRequest) GetDestination() string
- func (m *AuthnRequest) GetID() string
- func (m *AuthnRequest) GetIssueInstant() *google_protobuf.Timestamp
- func (m *AuthnRequest) GetIssuer() string
- func (m *AuthnRequest) GetProtocolBinding() string
- func (m *AuthnRequest) GetRelayState() string
- func (m *AuthnRequest) GetVersion() string
- func (*AuthnRequest) ProtoMessage()
- func (m *AuthnRequest) Reset()
- func (m *AuthnRequest) String() string
- type User
- func (u *User) AppendAttributes(atts []*Attribute)
- func (u *User) AttributeStatement() *saml.AttributeStatement
- func (*User) Descriptor() ([]byte, []int)
- func (m *User) GetAttributes() []*Attribute
- func (m *User) GetContext() string
- func (m *User) GetFormat() string
- func (m *User) GetIP() string
- func (m *User) GetName() string
- func (*User) ProtoMessage()
- func (m *User) Reset()
- func (m *User) String() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArtifactResponse ¶
type ArtifactResponse struct {
User *User `protobuf:"bytes,1,opt,name=User" json:"User,omitempty"`
Request *AuthnRequest `protobuf:"bytes,2,opt,name=Request" json:"Request,omitempty"`
}
Allows storage of data required for artifact response until service provider retrieves it
func (*ArtifactResponse) Descriptor ¶
func (*ArtifactResponse) Descriptor() ([]byte, []int)
func (*ArtifactResponse) GetRequest ¶
func (m *ArtifactResponse) GetRequest() *AuthnRequest
func (*ArtifactResponse) GetUser ¶
func (m *ArtifactResponse) GetUser() *User
func (*ArtifactResponse) ProtoMessage ¶
func (*ArtifactResponse) ProtoMessage()
func (*ArtifactResponse) Reset ¶
func (m *ArtifactResponse) Reset()
func (*ArtifactResponse) String ¶
func (m *ArtifactResponse) String() string
type Attribute ¶
type Attribute struct {
Name string `protobuf:"bytes,1,opt,name=Name" json:"Name,omitempty"`
Value []string `protobuf:"bytes,2,rep,name=Value" json:"Value,omitempty"`
}
User attributes
func (*Attribute) Descriptor ¶
func (*Attribute) ProtoMessage ¶
func (*Attribute) ProtoMessage()
type AuthnRequest ¶
type AuthnRequest struct {
ID string `protobuf:"bytes,1,opt,name=ID" json:"ID,omitempty"`
Version string `protobuf:"bytes,2,opt,name=Version" json:"Version,omitempty"`
IssueInstant *google_protobuf.Timestamp `protobuf:"bytes,3,opt,name=IssueInstant" json:"IssueInstant,omitempty"`
Issuer string `protobuf:"bytes,4,opt,name=Issuer" json:"Issuer,omitempty"`
Destination string `protobuf:"bytes,5,opt,name=Destination" json:"Destination,omitempty"`
AssertionConsumerServiceURL string `protobuf:"bytes,6,opt,name=AssertionConsumerServiceURL" json:"AssertionConsumerServiceURL,omitempty"`
ProtocolBinding string `protobuf:"bytes,7,opt,name=ProtocolBinding" json:"ProtocolBinding,omitempty"`
AssertionConsumerServiceIndex uint32 `protobuf:"varint,8,opt,name=AssertionConsumerServiceIndex" json:"AssertionConsumerServiceIndex,omitempty"`
RelayState string `protobuf:"bytes,9,opt,name=RelayState" json:"RelayState,omitempty"`
}
Allows storage of the request for cases where there is a user wait state such as entering a password
func NewAuthnRequest ¶
func NewAuthnRequest(src *saml.AuthnRequest, relayState string) (*AuthnRequest, error)
func (*AuthnRequest) Descriptor ¶
func (*AuthnRequest) Descriptor() ([]byte, []int)
func (*AuthnRequest) GetAssertionConsumerServiceIndex ¶
func (m *AuthnRequest) GetAssertionConsumerServiceIndex() uint32
func (*AuthnRequest) GetAssertionConsumerServiceURL ¶
func (m *AuthnRequest) GetAssertionConsumerServiceURL() string
func (*AuthnRequest) GetDestination ¶
func (m *AuthnRequest) GetDestination() string
func (*AuthnRequest) GetID ¶
func (m *AuthnRequest) GetID() string
func (*AuthnRequest) GetIssueInstant ¶
func (m *AuthnRequest) GetIssueInstant() *google_protobuf.Timestamp
func (*AuthnRequest) GetIssuer ¶
func (m *AuthnRequest) GetIssuer() string
func (*AuthnRequest) GetProtocolBinding ¶
func (m *AuthnRequest) GetProtocolBinding() string
func (*AuthnRequest) GetRelayState ¶
func (m *AuthnRequest) GetRelayState() string
func (*AuthnRequest) GetVersion ¶
func (m *AuthnRequest) GetVersion() string
func (*AuthnRequest) ProtoMessage ¶
func (*AuthnRequest) ProtoMessage()
func (*AuthnRequest) Reset ¶
func (m *AuthnRequest) Reset()
func (*AuthnRequest) String ¶
func (m *AuthnRequest) String() string
type User ¶
type User struct {
Name string `protobuf:"bytes,1,opt,name=Name" json:"Name,omitempty"`
Format string `protobuf:"bytes,2,opt,name=Format" json:"Format,omitempty"`
Context string `protobuf:"bytes,3,opt,name=Context" json:"Context,omitempty"`
IP string `protobuf:"bytes,4,opt,name=IP" json:"IP,omitempty"`
Attributes []*Attribute `protobuf:"bytes,5,rep,name=Attributes" json:"Attributes,omitempty"`
}
Allows storage of user information to avoid repeated logins, basis of SSO
func (*User) AppendAttributes ¶
func (*User) AttributeStatement ¶
func (u *User) AttributeStatement() *saml.AttributeStatement
func (*User) Descriptor ¶
func (*User) GetAttributes ¶
func (*User) GetContext ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
Click to show internal directories.
Click to hide internal directories.